package com.yc.education.service;

import com.yc.education.model.Technology;

import java.util.List;

/**
 * huangpan
 * 2019/10/8
 * energy
 */
public interface TechnologyService extends IService<Technology>  {
    /*查询所有*/
    List<Technology> selectAllTechnology(Integer pageNum, Integer pageSize, String titleName);

    /*查询单条记录*/
    Technology selectTechnologyById(int id);

    /*删除单条*/
    void deleteTechnologyById(int id);

    /*首页ICON查询*/
    List<Technology> iconTechnology();

    /*列表查询*/
    List<Technology> tTechnology ();

}
